# warframe-metrics

Analysis tool for warframe market.

## 📈 Warframe Metrics Warframe market is an excellent tool for all of us traders. However, what about the metrics that all traders require to make intillegent desicions. This library looks to extend the possible analysis based on the data provided openly by warframe market. - Free software: MIT license ## 📚 Documentation Documentation is currently a work in progress. ## 📦 Installing You can install `warframe-metrics` using pip:: $ pip install warframe-metrics ## 📤 Credit All credit goes to https://warframe.market/ and their creators for enabling this project and the data used within it. ## ⚙ Using Coming soon... # 👷 Contributing Contributions are welcome. To learn more, see the [Contributor Guide][]. # 📕 License Distributed under the terms of the [MIT][] license, _warframe-metrics_ is free and open source software. # 💥 Issues If you encounter any issues or problems, please [file an issue][] along with a detailed description. [contributor guide]: https://warframe-metrics.readthedocs.io/en/latest/contributor_guide/ [mit]: http://opensource.org/licenses/MIT [file an issue]: https://github.com/rajivsarvepalli/warframe-metrics/issues